ComplExInteraction
==================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ComplExInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ComplExInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
